---
title: 'CloudDrift: accelerating the use of Lagrangian data for atmospheric, oceanic, and climate sciences'
tags:
  - python
  - oceanography
  - global drifter program
  - cloud computing
authors:
- name: Philippe Miron
  orcid: 0000-0002-8520-6221
  affiliation: 1 # (Multiple affiliations must be quoted)
- name: Shane Elipot
  orcid: 0000-0001-6051-5426
  affiliation: 2 # (Multiple affiliations must be quoted)
#  - name: Author Without ORCID^[co-first author] # note this makes a footnote saying 'co-first author'
#    affiliation: 2
affiliations:
 - name: Center for Ocean-Atmospheric Prediction Studies, Florida State University, Tallahassee, Fl
   index: 1
 - name: Rosenstiel School of Marine and Atmospheric Science, University of Miami, Miami, Fl
   index: 2
date: 1 December 2021
bibliography: paper.bib

# Optional fields if submitting to a AAS journal too, see this blog post:
# https://blog.joss.theoj.org/2018/12/a-new-collaboration-with-aas-publishing
#aas-doi: 10.3847/xxxxx <- update this with the DOI from AAS once you know it.
#aas-journal: Astrophysical Journal <- The name of the AAS journal.
---

# Summary

CloudDrift is a library to accelerate the use of Lagrangian data sets.

# Statement of need

# Key Features

## Data

## Toolbox


<!---
# Mathematics

Single dollars ($) are required for inline mathematics e.g. $f(x) = e^{\pi/x}$

Double dollars make self-standing equations:

$$\Theta(x) = \left\{\begin{array}{l}
0\textrm{ if } x < 0\cr
1\textrm{ else}
\end{array}\right.$$

You can also use plain \LaTeX for equations
\begin{equation}\label{eq:fourier}
\hat f(\omega) = \int_{-\infty}^{\infty} f(x) e^{i\omega x} dx
\end{equation}
and refer to \autoref{eq:fourier} from text.
--->

# Citations

For a quick reference, the following citation commands can be used:
- `@author:2001`  ->  "Author et al. (2001)"
- `[@author:2001]` -> "(Author et al., 2001)"
- `[@author1:2001; @author2:2001]` -> "(Author1 et al., 2001; Author2 et al., 2002)"

# Figures

Figures can be included like this:
![Caption for example figure.\label{fig:example}](figure.png)
and referenced from text using \autoref{fig:example}.

Figure sizes can be customized by adding an optional second parameter:
![Caption for example figure.](figure.png){ width=20% }

# Acknowledgements

We acknowledge contributions ...

# References
